==> distribution-5.57.0.zip: drr/regulation/common/validation/exists/SECPartyInformationOnlyExistsValidator.java <==
package drr.regulation.common.validation.exists;

import com.google.common.collect.ImmutableMap;
import com.rosetta.model.lib.path.RosettaPath;
import com.rosetta.model.lib.validation.ExistenceChecker;
import com.rosetta.model.lib.validation.ValidationResult;
import com.rosetta.model.lib.validation.ValidatorWithArg;
import drr.regulation.common.SECEntityClassificationEnum;
import drr.regulation.common.SECPartyInformation;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

import static com.rosetta.model.lib.validation.ValidationResult.failure;
import static com.rosetta.model.lib.validation.ValidationResult.success;

public class SECPartyInformationOnlyExistsValidator implements ValidatorWithArg<SECPartyInformation, Set<String>> {

	/* Casting is required to ensure types are output to ensure recompilation in Rosetta */
	@Override
	public <T2 extends SECPartyInformation> ValidationResult<SECPartyInformation> validate(RosettaPath path, T2 o, Set<String> fields) {
		Map<String, Boolean> fieldExistenceMap = ImmutableMap.<String, Boolean>builder()
				.put("entityClassification", ExistenceChecker.isSet((SECEntityClassificationEnum) o.getEntityClassification()))
				.build();
		
		// Find the fields that are set
		Set<String> setFields = fieldExistenceMap.entrySet().stream()
				.filter(Map.Entry::getValue)
				.map(Map.Entry::getKey)
				.collect(Collectors.toSet());
		
		if (setFields.equals(fields)) {
			return success("SECPartyInformation", ValidationResult.ValidationType.ONLY_EXISTS, "SECPartyInformation", path, "");
		}
		return failure("SECPartyInformation", ValidationResult.ValidationType.ONLY_EXISTS, "SECPartyInformation", path, "",
				String.format("[%s] should only be set.  Set fields: %s", fields, setFields));
	}
}

==> distribution-6.0.0-dev.128.zip: drr/regulation/common/validation/exists/SECPartyInformationOnlyExistsValidator.java <==
package drr.regulation.common.validation.exists;

import com.google.common.collect.ImmutableMap;
import com.rosetta.model.lib.path.RosettaPath;
import com.rosetta.model.lib.validation.ExistenceChecker;
import com.rosetta.model.lib.validation.ValidationResult;
import com.rosetta.model.lib.validation.ValidationResult.ValidationType;
import com.rosetta.model.lib.validation.ValidatorWithArg;
import drr.regulation.common.SECEntityClassificationEnum;
import drr.regulation.common.SECPartyInformation;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

import static com.rosetta.model.lib.validation.ValidationResult.failure;
import static com.rosetta.model.lib.validation.ValidationResult.success;

public class SECPartyInformationOnlyExistsValidator implements ValidatorWithArg<SECPartyInformation, Set<String>> {

	/* Casting is required to ensure types are output to ensure recompilation in Rosetta */
	@Override
	public <T2 extends SECPartyInformation> ValidationResult<SECPartyInformation> validate(RosettaPath path, T2 o, Set<String> fields) {
		Map<String, Boolean> fieldExistenceMap = ImmutableMap.<String, Boolean>builder()
				.put("entityClassification", ExistenceChecker.isSet((SECEntityClassificationEnum) o.getEntityClassification()))
				.build();
		
		// Find the fields that are set
		Set<String> setFields = fieldExistenceMap.entrySet().stream()
				.filter(Map.Entry::getValue)
				.map(Map.Entry::getKey)
				.collect(Collectors.toSet());
		
		if (setFields.equals(fields)) {
			return success("SECPartyInformation", ValidationType.ONLY_EXISTS, "SECPartyInformation", path, "");
		}
		return failure("SECPartyInformation", ValidationType.ONLY_EXISTS, "SECPartyInformation", path, "",
				String.format("[%s] should only be set.  Set fields: %s", fields, setFields));
	}
}
